Welcome to the Logic-DS Library Repository
by the LogicDS Team, admin: Barnas Monteith, 2024

logic-ds is a Python library aimed at helping students learn functions; in this library we focus on creating functions that gradually introduce students to core programming concepts like inputs, outputs, return values, conditionals, and loops.

distributed as part of the LogicDS Project, housed at Texas Tech University, in conjunction with the University of FLorida, Center for Science Engagement and Concord Consortium
National Science Foundation Award #2201393.  This library is intended to be used as a python teaching library, to aid in student understanding of the universal framework concept of LogicDS, which emphasizes he use of logic and reasoning principles in the pedagogical approaches to teaching fundamental skills behind data science, including math/statistics, computer science as well as AI.
This library focuses on using alternative methods to aid in student understanding of functions with a focus on set theory, tuples, probability and linear regression.  The library is intended to be used along with the documentation and curricula provided through the LogicDS project courses and curricular framework.  

For library usage instructions, see /docs/DOCUMENTATION

More info about this project can be found at www.logicds.org

This library is distributed under the MIT License. see LICENSE file for additional information.


